@@ -22,6 +22,7 @@ from __future__ import annotations
 
 import asyncio
 import logging
+import os
 import re
 from abc import ABCMeta
 from collections import defaultdict, OrderedDict
@@ -42,6 +43,7 @@ from typing import (
     cast, Tuple
 )
 from quart import Quart
+from quart_cors import cors
 
 from wechaty_puppet import (
     get_logger,
@@ -190,6 +192,16 @@ class WechatyPlugin(metaclass=ABCMeta):
 
         return self.options.name
 
+    def cache_dir(self) -> str:
+        """
+        cache dir for plugin
+
+        this is friendly for code typing
+        """
+        _cache_dir = os.path.join('.wechaty', self.name)
+        os.makedirs(_cache_dir, exist_ok=True)
+        return _cache_dir
+
     @staticmethod
     def get_dependency_plugins() -> List[str]:
         """
@@ -318,7 +330,8 @@ class WechatyPluginManager:
         # supported now.
         self._dependency_tree: PluginTree = defaultdict()
 
-        self.app: Quart = Quart('Wechaty Server')
+        self.app: Quart = cors(Quart('Wechaty Server', static_folder=None))
+
         self.dependency_tree: PluginTree = defaultdict()
         self.endpoint: Tuple[str, int] = endpoint
 
